 /* This program uses high-frequency data to estimate the effect of the
   unanticipated changes in the conventional stance of monetary policy
   on bond yields of dollar-denominated sovereign bonds of different
   credit risk.
   NOTE:
   (1) Weighted (average) portfolio bond yields:
         - D#YTM_SG = #-day change in speculative-grade sovereign yields
         - D#YTM_IG = #-day change in the investment-grade sovereign yields
   (2) # = 2, 6 days
   (3) Monetary policy shock: DTREAS02Y_N
       NOTE: _N denotes intraday change in the narrow (30-minute) window
             bracketing an FOMC announcement.
   (4) Sample period: 06Feb1992--24Nov2008 and and 17Dec2015--20Mar2019
                      (conventional policy period)
   (5) Estimation method: OLS w/ robust standard errors
   (6) Results reported in Table 3
*/


	/* Set options: */
        #delimit;
	set more off;
	set linesize 255;
	capture log close; 
        mata: mata set matafavor speed;

        /* Output file: */
	capture log using "DYLD-CR-F1-CP.log", replace; 

	/* Read-in the data: */
	use "bond_wportfolio_cr.dta", clear;


        /* Sample period: */
        keep if ((date <= mdy(11,24,2008) & d9_11 == 0 & fomc == 1) | (date > mdy(12,17,2015) & fomc == 1));


       /****************************************************************************/

       /* Speculative-grade sovereign bond yields:
          NOTE: 2-day changes bracketing policy announcements. */
       reg d2ytm_sg dtreas02y_n, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;

       /* Investment-grade sovereign bond yields:
          NOTE: 2-day changes bracketing policy announcements. */
       reg d2ytm_ig dtreas02y_n, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;



       /* Speculative-grade sovereign bond yields:
          NOTE: 6-day changes bracketing policy announcements. */
       reg d6ytm_sg dtreas02y_n, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;

       /* Investment-grade sovereign bond yields:
          NOTE: 6-day changes bracketing policy announcements. */
       reg d6ytm_ig dtreas02y_n, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;
