/* This program uses high-frequency data to estimate the effect of the
   unanticipated changes in the conventional stance of monetary policy
   on dollar-denominated sovereign bond yields of different duration.
   NOTE:
   (1) Weighted (average) portfolio bond yields:
         - D#YTM_SD = #-day change in short duration sovereign bond yields
         - D#YTM_LD = #-day change in long duration sovereign bond yields
   (2) # = 2, 6 days
   (3) Monetary policy shock: DTREAS02Y_W1
       NOTE: _W1 denotes intraday change in the wide (60-minute) window
             bracketing an FOMC announcement.
   (4) Sample period: 25Nov2008--16Dec2015 (unconventional policy period)
   (5) Estimation method: OLS w/ robust standard errors
   (6) Results reported in Table 2
*/


	/* Set options: */
        #delimit;
	set more off;
	set linesize 255;
	capture log close; 
        mata: mata set matafavor speed;

        /* Output file: */
	capture log using "DYLD-DR-F1-UP.log", replace; 

	/* Read-in the data: */
	use "bond_wportfolio_dr.dta", clear;

        /* Sample period: */
        keep if date >= mdy(11,25,2008) & date <= mdy(12,16,2015) & (fomc == 1 | lsap == 1 | up_communication == 1);


       /****************************************************************************/

       /* Short duration sovereign bond yields:
          NOTE: 2-day changes bracketing policy announcements. */
       reg d2ytm_sd dtreas02y_w1, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;


       /* Long duration sovereign bond yields:
          NOTE: 2-day changes bracketing policy announcements. */
       reg d2ytm_ld dtreas02y_w1, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;


       /* Short duration sovereign bond yields:
          NOTE: 6-day changes bracketing policy announcements. */
       reg d6ytm_sd dtreas02y_w1, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;


       /* Long duration sovereign bond yields:
          NOTE: 6-day changes bracketing policy announcements. */
       reg d6ytm_ld dtreas02y_w1, r;
       fitstat;

       /* Test of the normality of residuals: */
       predict double _r, residuals;
       omninorm _r;
       drop _r;
